@@ -17,9 +17,8 @@ from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
-
-from .literals import SortOrderType
+from .literals import SortOrderTypeType
+from .paginator import ListSecretsPaginator
 from .type_defs import (
     CancelRotateSecretResponseTypeDef,
     CreateSecretResponseTypeDef,
@@ -82,7 +81,7 @@ class Exceptions:
 
 class SecretsManagerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -91,14 +90,14 @@ class SecretsManagerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_rotate_secret(self, SecretId: str) -> CancelRotateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
-        [Show boto3-stubs documentation](./client.md#cancel-rotate-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Show boto3-stubs documentation](./client.md#cancel_rotate_secret)
         """
 
     def create_secret(
@@ -114,14 +113,14 @@ class SecretsManagerClient:
         ForceOverwriteReplicaSecret: bool = None,
     ) -> CreateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
-        [Show boto3-stubs documentation](./client.md#create-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Show boto3-stubs documentation](./client.md#create_secret)
         """
 
     def delete_resource_policy(self, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
-        [Show boto3-stubs documentation](./client.md#delete-resource-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Show boto3-stubs documentation](./client.md#delete_resource_policy)
         """
 
     def delete_secret(
@@ -131,14 +130,14 @@ class SecretsManagerClient:
         ForceDeleteWithoutRecovery: bool = None,
     ) -> DeleteSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
-        [Show boto3-stubs documentation](./client.md#delete-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Show boto3-stubs documentation](./client.md#delete_secret)
         """
 
     def describe_secret(self, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
-        [Show boto3-stubs documentation](./client.md#describe-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Show boto3-stubs documentation](./client.md#describe_secret)
         """
 
     def generate_presigned_url(
@@ -149,8 +148,8 @@ class SecretsManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_random_password(
@@ -165,22 +164,22 @@ class SecretsManagerClient:
         RequireEachIncludedType: bool = None,
     ) -> GetRandomPasswordResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
-        [Show boto3-stubs documentation](./client.md#get-random-password)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Show boto3-stubs documentation](./client.md#get_random_password)
         """
 
     def get_resource_policy(self, SecretId: str) -> GetResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
-        [Show boto3-stubs documentation](./client.md#get-resource-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Show boto3-stubs documentation](./client.md#get_resource_policy)
         """
 
     def get_secret_value(
         self, SecretId: str, VersionId: str = None, VersionStage: str = None
     ) -> GetSecretValueResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
-        [Show boto3-stubs documentation](./client.md#get-secret-value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Show boto3-stubs documentation](./client.md#get_secret_value)
         """
 
     def list_secret_version_ids(
@@ -191,8 +190,8 @@ class SecretsManagerClient:
         IncludeDeprecated: bool = None,
     ) -> ListSecretVersionIdsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
-        [Show boto3-stubs documentation](./client.md#list-secret-version-ids)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Show boto3-stubs documentation](./client.md#list_secret_version_ids)
         """
 
     def list_secrets(
@@ -200,19 +199,19 @@ class SecretsManagerClient:
         MaxResults: int = None,
         NextToken: str = None,
         Filters: List[FilterTypeDef] = None,
-        SortOrder: SortOrderType = None,
+        SortOrder: SortOrderTypeType = None,
     ) -> ListSecretsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
-        [Show boto3-stubs documentation](./client.md#list-secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Show boto3-stubs documentation](./client.md#list_secrets)
         """
 
     def put_resource_policy(
         self, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = None
     ) -> PutResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
-        [Show boto3-stubs documentation](./client.md#put-resource-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Show boto3-stubs documentation](./client.md#put_resource_policy)
         """
 
     def put_secret_value(
@@ -224,16 +223,16 @@ class SecretsManagerClient:
         VersionStages: List[str] = None,
     ) -> PutSecretValueResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
-        [Show boto3-stubs documentation](./client.md#put-secret-value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Show boto3-stubs documentation](./client.md#put_secret_value)
         """
 
     def remove_regions_from_replication(
         self, SecretId: str, RemoveReplicaRegions: List[str]
     ) -> RemoveRegionsFromReplicationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
-        [Show boto3-stubs documentation](./client.md#remove-regions-from-replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
+        [Show boto3-stubs documentation](./client.md#remove_regions_from_replication)
         """
 
     def replicate_secret_to_regions(
@@ -243,14 +242,14 @@ class SecretsManagerClient:
         ForceOverwriteReplicaSecret: bool = None,
     ) -> ReplicateSecretToRegionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
-        [Show boto3-stubs documentation](./client.md#replicate-secret-to-regions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
+        [Show boto3-stubs documentation](./client.md#replicate_secret_to_regions)
         """
 
     def restore_secret(self, SecretId: str) -> RestoreSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
-        [Show boto3-stubs documentation](./client.md#restore-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Show boto3-stubs documentation](./client.md#restore_secret)
         """
 
     def rotate_secret(
@@ -261,26 +260,26 @@ class SecretsManagerClient:
         RotationRules: "RotationRulesTypeTypeDef" = None,
     ) -> RotateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
-        [Show boto3-stubs documentation](./client.md#rotate-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Show boto3-stubs documentation](./client.md#rotate_secret)
         """
 
     def stop_replication_to_replica(self, SecretId: str) -> StopReplicationToReplicaResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
-        [Show boto3-stubs documentation](./client.md#stop-replication-to-replica)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
+        [Show boto3-stubs documentation](./client.md#stop_replication_to_replica)
         """
 
     def tag_resource(self, SecretId: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, SecretId: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_secret(
@@ -293,8 +292,8 @@ class SecretsManagerClient:
         SecretString: str = None,
     ) -> UpdateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
-        [Show boto3-stubs documentation](./client.md#update-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Show boto3-stubs documentation](./client.md#update_secret)
         """
 
     def update_secret_version_stage(
@@ -305,19 +304,19 @@ class SecretsManagerClient:
         MoveToVersionId: str = None,
     ) -> UpdateSecretVersionStageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
-        [Show boto3-stubs documentation](./client.md#update-secret-version-stage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Show boto3-stubs documentation](./client.md#update_secret_version_stage)
         """
 
     def validate_resource_policy(
         self, ResourcePolicy: str, SecretId: str = None
     ) -> ValidateResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
-        [Show boto3-stubs documentation](./client.md#validate-resource-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        [Show boto3-stubs documentation](./client.md#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](./paginators.md#listsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](./paginators.md#listsecretspaginator)
         """
