@@ -22,7 +22,7 @@ from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import SortOrderType
+from .literals import SortOrderTypeType
 from .type_defs import FilterTypeDef, ListSecretsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListSecretsPaginator",)
@@ -30,16 +30,16 @@ __all__ = ("ListSecretsPaginator",)
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](./paginators.md#listsecretspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](./paginators.md#listsecretspaginator)
     """
 
     def paginate(
         self,
         Filters: List[FilterTypeDef] = None,
-        SortOrder: SortOrderType = None,
+        SortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
         [Show boto3-stubs documentation](./paginators.md#listsecretspaginator)
         """
